@@ -36,8 +36,8 @@ $juser = JFactory::getUser();
 
 $submissions = null;
 if (!$juser->get('guest')) {
-	$query  = "SELECT DISTINCT R.id, R.title, R.type, R.logical_type AS logicaltype, 
-						AA.subtable, R.created, R.created_by, R.published, R.publish_up, R.standalone, 
+	$query  = "SELECT DISTINCT R.id, R.title, R.type, R.logical_type AS logicaltype,
+						AA.subtable, R.created, R.created_by, R.published, R.publish_up, R.standalone,
 						R.rating, R.times_rated, R.alias, R.ranking, rt.type AS typetitle ";
 	$query .= "FROM #__author_assoc AS AA, #__resource_types AS rt, #__resources AS R ";
 	$query .= "LEFT JOIN #__resource_types AS t ON R.logical_type=t.id ";
@@ -50,104 +50,100 @@ if (!$juser->get('guest')) {
 	$database->setQuery($query);
 	$submissions = $database->loadObjectList();
 }
+
+$this->css('introduction.css', 'system')
+     ->css('create.css');
 ?>
-<div id="content-header" class="full">
+<header id="content-header">
 	<h2><?php echo $this->title; ?></h2>
-</div><!-- / #content-header -->
+</header><!-- / #content-header -->
 
-<div id="introduction" class="contribute section">
-	<div class="aside">
-		<p id="getstarted"><a href="<?php echo JRoute::_('index.php?option='.$this->option.'&task=draft'); ?>">Get Started &rsaquo;</a></p>
-	</div><!-- / .aside -->
-	<div class="subject">
-		<div class="grid">
-		<div class="col span-half">
-			<h3>Present your work!</h3>
-			<p>Become a contributor and share your work with the community! Contributing content is easy. Our step-by-step forms will guide you through the process.</p>
+<section id="introduction" class="contribute section">
+	<div class="grid">
+		<div class="col span9">
+			<div class="col span6">
+				<h3>Present your work!</h3>
+				<p>Become a contributor and share your work with the community! Contributing content is easy. Our step-by-step forms will guide you through the process.</p>
+			</div>
+			<div class="col span6 omega">
+				<h3>What do I need?</h3>
+				<p>The submission process will guide you through step-by-step, but for more detailed instructions on what can be submitted and how, please see the list of submission types below.</p>
+			</div>
 		</div>
-		<div class="col span-half omega">
-			<h3>What do I need?</h3>
-			<p>The submission process will guide you through step-by-step, but for more detailed instructions on what can be submitted and how, please see the list of submission types below.</p>
-		</div>
-		</div>
-	</div><!-- / .subject -->
-	<div class="clear"></div>
-</div><!-- / #introduction.section -->
+		<div class="col span3 omega">
+			<p id="getstarted">
+				<a class="btn btn-primary" href="<?php echo JRoute::_('index.php?option='.$this->option.'&task=draft'); ?>">Get Started &rsaquo;</a>
+			</p>
+		</div><!-- / .aside -->
+	</div>
+</section><!-- / #introduction.section -->
 
-<div class="section">
+<section class="section">
 
 <?php if (!$juser->get('guest')) { ?>
-<div class="grid">
-	<div class="col span3">
-		<h2><?php echo JText::_('In Progress'); ?></h2>
-	</div><!-- / .col span3 -->
-	<div class="col span9 omega">
-<?php
-		if ($submissions) {
-?>
-		<table id="submissions" summary="<?php echo JText::_('Contributions in progress'); ?>">
-			<thead>
-				<tr>
-					<th scope="col"><?php echo JText::_('Title'); ?></th>
-					<th scope="col" colspan="3"><?php echo JText::_('Associations'); ?></th>
-					<th scope="col" colspan="2"><?php echo JText::_('Status'); ?></th>
-				</tr>
-			</thead>
-			<tbody>
-<?php
-			$ra = new ResourcesAssoc( $database );
-			$rc = new ResourcesContributor( $database );
-			$rt = new ResourcesTags( $database );
-			$cls = 'even';
-			foreach ($submissions as $submission)
-			{
-				$cls = ($cls == 'even') ? 'odd' : 'even';
+	<div class="grid">
+		<div class="col span3">
+			<h2><?php echo JText::_('In Progress'); ?></h2>
+		</div><!-- / .col span3 -->
+		<div class="col span9 omega">
+		<?php if ($submissions) { ?>
+			<table id="submissions">
+				<thead>
+					<tr>
+						<th scope="col"><?php echo JText::_('Title'); ?></th>
+						<th scope="col" colspan="3"><?php echo JText::_('Associations'); ?></th>
+						<th scope="col" colspan="2"><?php echo JText::_('Status'); ?></th>
+					</tr>
+				</thead>
+				<tbody>
+				<?php
+					$ra = new ResourcesAssoc( $database );
+					$rc = new ResourcesContributor( $database );
+					$rt = new ResourcesTags( $database );
+					$cls = 'even';
+					foreach ($submissions as $submission)
+					{
+						$cls = ($cls == 'even') ? 'odd' : 'even';
 
-				switch ($submission->published)
-				{
-					case 1: $state = 'published';  break;  // published
-					case 2: $state = 'draft';      break;  // draft
-					case 3: $state = 'pending';    break;  // pending
-				}
+						switch ($submission->published)
+						{
+							case 1: $state = 'published';  break;  // published
+							case 2: $state = 'draft';      break;  // draft
+							case 3: $state = 'pending';    break;  // pending
+						}
 
-				$attachments = $ra->getCount( $submission->id );
+						$attachments = $ra->getCount( $submission->id );
 
-				$authors = $rc->getCount( $submission->id, 'resources' );
+						$authors = $rc->getCount( $submission->id, 'resources' );
 
-				$tags = $rt->getTags( $submission->id );
-?>
-				<tr class="<?php echo $cls; ?>">
-					<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=1&id='.$submission->id); ?>"><?php } ?><?php echo stripslashes($submission->title); ?><?php if ($submission->published == 2) { ?></a><?php } ?><br /><span class="type"><?php echo stripslashes($submission->typetitle); ?></span></td>
-					<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=2&id='.$submission->id); ?>"><?php } ?><?php echo $attachments; ?> attachment(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
-					<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=3&id='.$submission->id); ?>"><?php } ?><?php echo $authors; ?> author(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
-					<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=4&id='.$submission->id); ?>"><?php } ?><?php echo count($tags); ?> tag(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
-					<td>
-						<span class="<?php echo $state; ?> status"><?php echo $state; ?></span>
-						<?php if ($submission->published == 2) { ?>
-						<br /><a class="review" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=5&id='.$submission->id); ?>"><?php echo JText::_('Review &amp; Submit &rsaquo;'); ?></a>
-						<?php } elseif ($submission->published == 3) { ?>
-						<br /><a class="retract" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=retract&id='.$submission->id); ?>"><?php echo JText::_('&lsaquo; Retract'); ?></a>
-						<?php } ?>
-					</td>
-					<td><a class="icon-delete" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=discard&id='.$submission->id); ?>" title="<?php echo JText::_('Delete'); ?>"><?php echo JText::_('Delete'); ?></a></td>
-				</tr>
-<?php
-			}
-?>
-			</tbody>
-		</table>
-<?php
-		} else {
-?>
-		<p class="info">
-			<strong>You currently have no contributions in progress.</strong><br /><br />
-			Once you've started a new contribution, you can proceed at your leisure. Stop half-way through and watch a presentation, go to lunch, even close the browser and come back a different day! Your contribution will be waiting just as you left it, ready to continue at any time.
-		</p>
-<?php 
-		}
-?>
-	</div><!-- / .col span9 omega -->
-</div>
+						$tags = $rt->getTags( $submission->id );
+					?>
+					<tr class="<?php echo $cls; ?>">
+						<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=1&id='.$submission->id); ?>"><?php } ?><?php echo stripslashes($submission->title); ?><?php if ($submission->published == 2) { ?></a><?php } ?><br /><span class="type"><?php echo stripslashes($submission->typetitle); ?></span></td>
+						<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=2&id='.$submission->id); ?>"><?php } ?><?php echo $attachments; ?> attachment(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
+						<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=3&id='.$submission->id); ?>"><?php } ?><?php echo $authors; ?> author(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
+						<td><?php if ($submission->published == 2) { ?><a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=4&id='.$submission->id); ?>"><?php } ?><?php echo count($tags); ?> tag(s)<?php if ($submission->published == 2) { ?></a><?php } ?></td>
+						<td>
+							<span class="<?php echo $state; ?> status"><?php echo $state; ?></span>
+							<?php if ($submission->published == 2) { ?>
+							<br /><a class="review" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=draft&step=5&id='.$submission->id); ?>"><?php echo JText::_('Review &amp; Submit &rsaquo;'); ?></a>
+							<?php } elseif ($submission->published == 3) { ?>
+							<br /><a class="retract" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=retract&id='.$submission->id); ?>"><?php echo JText::_('&lsaquo; Retract'); ?></a>
+							<?php } ?>
+						</td>
+						<td><a class="icon-delete" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=discard&id='.$submission->id); ?>" title="<?php echo JText::_('Delete'); ?>"><?php echo JText::_('Delete'); ?></a></td>
+					</tr>
+				<?php } ?>
+				</tbody>
+			</table>
+		<?php } else { ?>
+			<p class="info">
+				<strong>You currently have no contributions in progress.</strong><br /><br />
+				Once you've started a new contribution, you can proceed at your leisure. Stop half-way through and watch a presentation, go to lunch, even close the browser and come back a different day! Your contribution will be waiting just as you left it, ready to continue at any time.
+			</p>
+		<?php } ?>
+		</div><!-- / .col span9 omega -->
+	</div>
 <?php } ?>
 
 	<div class="grid">
@@ -185,7 +181,7 @@ if ($categories) {
 
 		foreach ($categories as $category)
 		{
-			if ($category->contributable != 1) 
+			if ($category->contributable != 1)
 			{
 				continue;
 			}
@@ -240,4 +236,4 @@ if ($categories) {
 }
 ?>
 
-</div><!-- / .section -->
+</section><!-- / .section -->
