@@ -43,10 +43,10 @@ defined('_JEXEC') or die('Restricted access');
 
 	$name = JText::_('PLG_GROUPS_FORUM_ANONYMOUS');
 	$huser = '';
-	if (!$this->comment->get('anonymous')) 
+	if (!$this->comment->get('anonymous'))
 	{
 		$huser = \Hubzero\User\Profile::getInstance($this->comment->get('created_by'));
-		if (is_object($huser) && $huser->get('name')) 
+		if (is_object($huser) && $huser->get('name'))
 		{
 			$name = '<a href="' . JRoute::_('index.php?option=com_members&id=' . $this->comment->get('created_by')) . '">' . $this->escape(stripslashes($huser->get('name'))) . '</a>';
 		}
@@ -54,7 +54,7 @@ defined('_JEXEC') or die('Restricted access');
 
 	$cls = isset($this->cls) ? $this->cls : 'odd';
 
-	if ($this->comment->get('reports'))
+	if ($this->comment->isReported())
 	{
 		$comment = '<p class="warning">' . JText::_('PLG_GROUPS_FORUM_COMMENT_REPORTED') . '</p>';
 	}
@@ -69,17 +69,17 @@ defined('_JEXEC') or die('Restricted access');
 		</p>
 		<div class="comment-content">
 			<p class="comment-title">
-				<strong><?php echo $name; ?></strong> 
+				<strong><?php echo $name; ?></strong>
 				<a class="permalink" href="<?php echo JRoute::_($this->comment->link('anchor')); ?>" title="<?php echo JText::_('PLG_GROUPS_FORUM_PERMALINK'); ?>">
-					<span class="comment-date-at"><?php echo JText::_('PLG_GROUPS_FORUM_AT'); ?></span> 
-					<span class="time"><time datetime="<?php echo $this->comment->created(); ?>"><?php echo $this->comment->created('time'); ?></time></span> 
-					<span class="comment-date-on"><?php echo JText::_('PLG_GROUPS_FORUM_ON'); ?></span> 
+					<span class="comment-date-at"><?php echo JText::_('PLG_GROUPS_FORUM_AT'); ?></span>
+					<span class="time"><time datetime="<?php echo $this->comment->created(); ?>"><?php echo $this->comment->created('time'); ?></time></span>
+					<span class="comment-date-on"><?php echo JText::_('PLG_GROUPS_FORUM_ON'); ?></span>
 					<span class="date"><time datetime="<?php echo $this->comment->created(); ?>"><?php echo $this->comment->created('date'); ?></time></span>
 					<?php if ($this->comment->wasModified()) { ?>
 						&mdash; <?php echo JText::_('PLG_GROUPS_FORUM_EDITED'); ?>
-						<span class="comment-date-at"><?php echo JText::_('PLG_GROUPS_FORUM_AT'); ?></span> 
-						<span class="time"><time datetime="<?php echo $this->comment->modified(); ?>"><?php echo $this->comment->modified('time'); ?></time></span> 
-						<span class="comment-date-on"><?php echo JText::_('PLG_GROUPS_FORUM_ON'); ?></span> 
+						<span class="comment-date-at"><?php echo JText::_('PLG_GROUPS_FORUM_AT'); ?></span>
+						<span class="time"><time datetime="<?php echo $this->comment->modified(); ?>"><?php echo $this->comment->modified('time'); ?></time></span>
+						<span class="comment-date-on"><?php echo JText::_('PLG_GROUPS_FORUM_ON'); ?></span>
 						<span class="date"><time datetime="<?php echo $this->comment->modified(); ?>"><?php echo $this->comment->modified('date'); ?></time></span>
 					<?php } ?>
 				</a>
@@ -90,41 +90,41 @@ defined('_JEXEC') or die('Restricted access');
 			<p class="comment-options">
 			<?php if (
 						$this->config->get('access-manage-thread')
-					 || $this->config->get('access-delete-thread') 
+					 || $this->config->get('access-delete-thread')
 					 || $this->config->get('access-edit-thread')
-					 || $this->config->get('access-delete-post') 
+					 || $this->config->get('access-delete-post')
 					 || $this->config->get('access-edit-post')
 					) { ?>
 				<?php if ($this->comment->get('parent') && $this->config->get('access-delete-post')) { ?>
-					<a class="icon-delete delete" data-id="c<?php echo $this->comment->get('id'); ?>" href="<?php echo JRoute::_($this->comment->link('delete')); ?>"><!-- 
-						--><?php echo JText::_('PLG_GROUPS_FORUM_DELETE'); ?><!-- 
+					<a class="icon-delete delete" data-id="c<?php echo $this->comment->get('id'); ?>" href="<?php echo JRoute::_($this->comment->link('delete')); ?>"><!--
+						--><?php echo JText::_('PLG_GROUPS_FORUM_DELETE'); ?><!--
 					--></a>
 				<?php } ?>
 				<?php if ($this->config->get('access-edit-thread') || $this->config->get('access-edit-post')) { ?>
-					<a class="icon-edit edit" data-id="c<?php echo $this->comment->get('id'); ?>" href="<?php echo JRoute::_($this->comment->link('edit')); ?>"><!-- 
-						--><?php echo JText::_('PLG_GROUPS_FORUM_EDIT'); ?><!-- 
+					<a class="icon-edit edit" data-id="c<?php echo $this->comment->get('id'); ?>" href="<?php echo JRoute::_($this->comment->link('edit')); ?>"><!--
+						--><?php echo JText::_('PLG_GROUPS_FORUM_EDIT'); ?><!--
 					--></a>
 				<?php } ?>
 			<?php } ?>
 
-			<?php if (!$this->comment->get('reports')) { ?>
+			<?php if (!$this->comment->isReported()) { ?>
 				<?php if (!$this->thread->get('closed') && $this->config->get('threading') == 'tree' && $this->depth < $this->config->get('threading_depth', 3)) { ?>
 					<?php if (JRequest::getInt('reply', 0) == $this->comment->get('id')) { ?>
-					<a class="icon-reply reply active" data-txt-active="<?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?>" data-txt-inactive="<?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?>" href="<?php echo JRoute::_($this->comment->link()); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!-- 
-					--><?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?><!-- 
+					<a class="icon-reply reply active" data-txt-active="<?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?>" data-txt-inactive="<?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?>" href="<?php echo JRoute::_($this->comment->link()); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!--
+					--><?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?><!--
 				--></a>
 					<?php } else { ?>
-					<a class="icon-reply reply" data-txt-active="<?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?>" data-txt-inactive="<?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?>" href="<?php echo JRoute::_($this->comment->link('reply')); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!-- 
-					--><?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?><!-- 
+					<a class="icon-reply reply" data-txt-active="<?php echo JText::_('PLG_GROUPS_FORUM_CANCEL'); ?>" data-txt-inactive="<?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?>" href="<?php echo JRoute::_($this->comment->link('reply')); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!--
+					--><?php echo JText::_('PLG_GROUPS_FORUM_REPLY'); ?><!--
 				--></a>
 					<?php } ?>
 				<?php } ?>
-				<a class="icon-abuse abuse" href="<?php echo JRoute::_($this->comment->link('abuse')); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!-- 
-					--><?php echo JText::_('PLG_GROUPS_FORUM_REPORT_ABUSE'); ?><!-- 
+				<a class="icon-abuse abuse" href="<?php echo JRoute::_($this->comment->link('abuse')); ?>" rel="comment-form<?php echo $this->comment->get('id'); ?>"><!--
+					--><?php echo JText::_('PLG_GROUPS_FORUM_REPORT_ABUSE'); ?><!--
 				--></a>
 			<?php } ?>
 			</p>
-			
+
 
 		<?php if (!$this->thread->get('closed') && $this->config->get('threading') == 'tree' && $this->depth < $this->config->get('threading_depth', 3)) { ?>
 			<div class="comment-add<?php if (JRequest::getInt('reply', 0) != $this->comment->get('id')) { echo ' hide'; } ?>" id="comment-form<?php echo $this->comment->get('id'); ?>">
@@ -164,12 +164,12 @@ defined('_JEXEC') or die('Restricted access');
 						</label>
 
 						<label class="reply-anonymous-label" for="comment-<?php echo $this->comment->get('id'); ?>-anonymous">
-							<input class="option" type="checkbox" name="fields[anonymous]" id="comment-<?php echo $this->comment->get('id'); ?>-anonymous" value="1" /> 
+							<input class="option" type="checkbox" name="fields[anonymous]" id="comment-<?php echo $this->comment->get('id'); ?>-anonymous" value="1" />
 							<?php echo JText::_('PLG_GROUPS_FORUM_FIELD_ANONYMOUS'); ?>
 						</label>
 
 						<p class="submit">
-							<input type="submit" value="<?php echo JText::_('PLG_GROUPS_FORUM_SUBMIT'); ?>" /> 
+							<input type="submit" value="<?php echo JText::_('PLG_GROUPS_FORUM_SUBMIT'); ?>" />
 						</p>
 					</fieldset>
 				</form>
@@ -177,31 +177,20 @@ defined('_JEXEC') or die('Restricted access');
 		<?php } ?>
 		</div><!-- / .comment-content -->
 		<?php
-		if ($this->config->get('threading') == 'tree' && $this->depth < $this->config->get('threading_depth', 3)) 
+		if ($this->config->get('threading') == 'tree' && $this->depth < $this->config->get('threading_depth', 3))
 		{
-			$view = new \Hubzero\Plugin\View(
-				array(
-					'folder'  => 'groups',
-					'element' => 'forum',
-					'name'    => 'threads',
-					'layout'  => '_list'
-				)
-			);
-			$view->option     = $this->option;
-			$view->group      = $this->group;
-
-			$view->parent     = $this->comment->get('id');
-			$view->thread     = $this->comment->get('thread');
-			$view->comments   = $this->comment->get('replies');
-
-			$view->thread     = $this->thread;
-			$view->config     = $this->config;
-			$view->depth      = $this->depth;
-			$view->cls        = $cls;
-			$view->filters    = $this->filters;
-			$view->category   = $this->category;
-
-			$view->display();
+			$this->view('_list')
+			     ->set('option', $this->option)
+			     ->set('group', $this->group)
+			     ->set('comments', $this->comment->get('replies'))
+			     ->set('thread', $this->comment->get('thread'))
+			     ->set('parent', $this->comment->get('id'))
+			     ->set('config', $this->config)
+			     ->set('depth', $this->depth)
+			     ->set('cls', $cls)
+			     ->set('filters', $this->filters)
+			     ->set('category', $this->category)
+			     ->display();
 		}
 		?>
 	</li>
\ No newline at end of file
